[PPL-devel] [GIT] ppl/ppl(master): Comments improved.

Roberto Bagnara bagnara at cs.unipr.it
Fri Mar 27 21:06:32 CET 2009


Module: ppl/ppl
Branch: master
Commit: a1335e6212c7fb666cacc103b15e4cf450fee7a1
URL:    http://www.cs.unipr.it/git/gitweb.cgi?p=ppl/ppl.git;a=commit;h=a1335e6212c7fb666cacc103b15e4cf450fee7a1

Author: Roberto Bagnara <bagnara at cs.unipr.it>
Date:   Fri Mar 27 21:06:22 2009 +0100

Comments improved.

---

 interfaces/C/ppl_c_header.h |    6 +++---
 src/wrap.hh                 |    3 +--
 2 files changed, 4 insertions(+), 5 deletions(-)

diff --git a/src/wrap.hh b/src/wrap.hh
index 04e6c3b..0980885 100644
--- a/src/wrap.hh
+++ b/src/wrap.hh
@@ -29,7 +29,7 @@ namespace Parma_Polyhedra_Library {
 
 namespace IO_Operators {
 
-//! Helper function for the wrapping of lines.
+//! Utility function for the wrapping of lines of text.
 /*!
   \param src_string
   The source string holding the lines to wrap.
@@ -52,7 +52,6 @@ wrap_string(const std::string& src_string,
 	    unsigned preferred_first_line_length,
 	    unsigned preferred_line_length);
 
-
 } // namespace IO_Operators
 
 } // namespace Parma_Polyhedra_Library




More information about the PPL-devel mailing list
diff --git a/interfaces/C/ppl_c_header.h b/interfaces/C/ppl_c_header.h
index 8d83312..8b64573 100644
--- a/interfaces/C/ppl_c_header.h
+++ b/interfaces/C/ppl_c_header.h
@@ -398,10 +398,10 @@ ppl_io_set_variable_output_function(ppl_io_variable_output_function_type* p);
 int
 ppl_io_get_variable_output_function(ppl_io_variable_output_function_type** pp);
 
 /*! \brief Helper function for the wrapping of lines from C.
 
   \param src
-  The source string holding the lines to wrap.
+  The source string holding the text to wrap.
 
   \param indent_depth
   The indentation depth.
@@ -413,7 +413,7 @@ ppl_io_get_variable_output_function(ppl_io_variable_output_function_type** pp);
   The preferred length for all the lines but the first one.
 
   \return
-  The wrapped string in a mallocated buffer.
+  The wrapped string in a malloc-allocated buffer.
 */
 char*
 ppl_io_wrap_string(const char* src,
@@ -398,10 +398,10 @@ ppl_io_set_variable_output_function(ppl_io_variable_output_function_type* p);
 ppl_io_get_variable_output_function(ppl_io_variable_output_function_type** pp);
 
-/*! \brief Helper function for the wrapping of lines from C.
+/*! \brief Utility function for the wrapping of lines of text.
 
   \param src